#!/usr/bin/env python
# coding: utf-8
import value_tagrec.sim as sim

def tagrec(textStr, tagLevel=3, top=5, confidenceLowerBound=0):
    return sim.execute(textStr, tagLevel, top, confidenceLowerBound)


if __name__ == '__main__':

#     textStr = "《习近平关于中国特色大国外交论述摘编》出版发行\n \
# 　　新华社北京1月5日电  中共中央党史和文献研究院编辑的《习近平关于中国特色大国外交论述摘编》一书，近日由中央文献出版社出版，在全国发行。\n \
# 　　党的十八大以来，在以习近平同志为核心的党中央坚强领导下，面对国际形势风云变幻，我们开创性推进中国特色大国外交，我国对外工作砥砺前行、波澜壮阔，取得了历史性成就。习近平总书记深刻把握新时代中国和世界发展大势，在对外工作上进行一系列重大理论和实践创新，形成了习近平外交思想。习近平外交思想，是习近平新时代中国特色社会主义思想的重要组成部分，对于坚持党对外事工作的集中统一领导，统筹国内国际两个大局，牢牢把握服务民族复兴、促进人类进步这条主线，坚定维护国家主权、安全、发展利益，推动构建人类命运共同体，努力开创中国特色大国外交新局面，具有十分重要的指导意义。\n \
# 　　《论述摘编》共分10个专题：坚持以维护党中央权威为统领加强党对对外工作的集中统一领导；坚持以实现中华民族伟大复兴为使命推进中国特色大国外交；坚持以维护世界和平、促进共同发展为宗旨推动构建人类命运共同体；坚持以中国特色社会主义为根本增强战略自信；坚持以共商共建共享为原则推动“一带一路”建设；坚持以相互尊重、合作共赢为基础走和平发展道路；坚持以深化外交布局为依托打造全球伙伴关系；坚持以公平正义为理念引领全球治理体系改革；坚持以国家核心利益为底线维护国家主权、安全、发展利益；坚持以对外工作优良传统和时代特征相结合为方向塑造中国外交独特风范。书中收入504段论述，摘自习近平总书记2012年12月至2019年11月期间的讲话、谈话、报告、演讲、文章、贺信等190多篇重要文献。其中部分论述是第一次公开发表。\n"
#
    textStr = "全心全意为增强人民群众获得感、幸福感、安全感而努力工作"
    tagrec(textStr)